@@ -1,40 +1,32 @@
-use crate::goodies::{Time, Month};
+use crate::goodies::{Battery, Month, Time};
+use bytesize::ByteSize;
 use chrono::{Datelike, Timelike, Utc};
+use libmacchina::traits::BatteryReadout as _;
+use libmacchina::traits::GeneralReadout as _;
+use libmacchina::traits::MemoryReadout as _;
 use libmacchina::traits::ReadoutError;
 use libmacchina::BatteryReadout;
 use libmacchina::GeneralReadout;
 use libmacchina::MemoryReadout;
 
 pub fn uptime() -> Result<Time, ReadoutError> {
-    use libmacchina::traits::GeneralReadout as _;
-
-    let read = GeneralReadout::new();
-    if let Ok(up) = read.uptime() {
-        return Ok(Time::from(up));
+    match GeneralReadout::new().uptime() {
+        Ok(up) => Ok(Time::from(up)),
+        _ => Err(ReadoutError::Warning(
+            "I couldn't get this statistic :(".to_string(),
+        )),
     }
-
-    Err(ReadoutError::Warning(
-        "I couldn't get this statistic :(".to_string(),
-    ))
 }
 
 pub fn network(interface: Option<String>) -> Result<String, ReadoutError> {
-    use libmacchina::traits::GeneralReadout as _;
-
-    let read = GeneralReadout::new();
-
-    match read.local_ip(interface) {
-        Ok(ip) => Ok(format!("Local IP: {}\nState: Online", ip)),
+    match GeneralReadout::new().local_ip(interface) {
+        Ok(ip) => Ok(format!("Local IP: {}", ip)),
         Err(e) => Err(ReadoutError::Warning(e.to_string())),
     }
 }
 
 pub fn memory() -> Result<String, ReadoutError> {
-    use bytesize::ByteSize;
-    use libmacchina::traits::MemoryReadout as _;
-
     let read = MemoryReadout::new();
-
     match (read.used(), read.total()) {
         (Ok(u), Ok(t)) => {
             let total = ByteSize::kb(t);
@@ -50,18 +42,9 @@ pub fn memory() -> Result<String, ReadoutError> {
 }
 
 pub fn battery() -> Result<String, ReadoutError> {
-    use libmacchina::traits::BatteryReadout as _;
-
     let read = BatteryReadout::new();
     match (read.percentage(), read.status()) {
-        (Ok(p), Ok(s)) => match s {
-            libmacchina::traits::BatteryState::Charging => {
-                Ok(format!("Percentage: {}%\nState: Charging", p))
-            }
-            libmacchina::traits::BatteryState::Discharging => {
-                Ok(format!("Percentage: {}%\nState: Discharging", p))
-            }
-        },
+        (Ok(p), Ok(s)) => Ok(Battery::new(p, s).to_string()),
         _ => Err(ReadoutError::Warning(
             "I couldn't get this statistic :(".to_string(),
         )),
@@ -71,12 +54,16 @@ pub fn battery() -> Result<String, ReadoutError> {
 pub fn date_time() -> Result<String, ReadoutError> {
     let now = Utc::now();
     let (is_pm, hour) = now.hour12();
-    let date = format!("{}, {} {:02}", now.weekday(), Month::from(now.month()), now.day());
+    let date = format!(
+        "{}, {} {:02}",
+        now.weekday(),
+        Month::from(now.month()),
+        now.day()
+    );
     let time = format!(
-        "{:02}:{:02}:{:02} {}",
+        "{:02}:{:02} {}",
         hour,
         now.minute(),
-        now.second(),
         if is_pm { "PM" } else { "AM" }
     );
 
